@@ -7,6 +7,10 @@ from .constants import *
 import requests
 
 
+OAUTH2_SUBDOMAIN = 'api'
+OAUTH2_ENDPOINT = 'oauth2/token'
+
+
 class BearerAuth(requests.auth.AuthBase):
 
     """Request bearer access token for oAuth2 authentication.
@@ -24,9 +28,9 @@ class BearerAuth(requests.auth.AuthBase):
 
     def _get_access_token(self):
         token_url = '%s://%s.%s/%s' % (PROTOCOL,
-                                       REST_SUBDOMAIN,
+                                       OAUTH2_SUBDOMAIN,
                                        DOMAIN,
-                                       OAUTH2_TOKEN_ENDPOINT)
+                                       OAUTH2_ENDPOINT)
         auth = self._consumer_key + ':' + self._consumer_secret
         b64_bearer_token_creds = base64.b64encode(auth.encode('utf8'))
         params = {'grant_type': 'client_credentials'}
@@ -34,8 +38,8 @@ class BearerAuth(requests.auth.AuthBase):
         headers['User-Agent'] = USER_AGENT
         headers['Authorization'] = 'Basic ' + \
             b64_bearer_token_creds.decode('utf8')
-        headers[
-            'Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8'
+        headers['Content-Type'] = \
+            'application/x-www-form-urlencoded;charset=UTF-8'
         try:
             response = requests.post(
                 token_url,
@@ -45,9 +49,7 @@ class BearerAuth(requests.auth.AuthBase):
             data = response.json()
             return data['access_token']
         except Exception as e:
-            raise Exception(
-                'Error while requesting bearer access token: %s' %
-                e)
+            raise Exception('Error requesting bearer access token: %s' % e)
 
     def __call__(self, r):
         auth_list = [
